@@ -37,6 +37,9 @@ from hexbytes import (
 from web3._utils.blocks import (
     select_method_for_block_identifier,
 )
+from web3._utils.decorators import (
+    deprecated_for,
+)
 from web3._utils.empty import (
     Empty,
     empty,
@@ -122,6 +125,10 @@ class Eth(ModuleV2, Module):
 
     @property
     def protocol_version(self) -> str:
+        warnings.warn(
+            "This method has been deprecated in some clients.",
+            category=DeprecationWarning,
+        )
         return self._protocol_version()
 
     @property
@@ -194,14 +201,14 @@ class Eth(ModuleV2, Module):
     def accounts(self) -> Tuple[ChecksumAddress]:
         return self.get_accounts()
 
-    _block_number: Method[Callable[[], BlockNumber]] = Method(
+    get_block_number: Method[Callable[[], BlockNumber]] = Method(
         RPC.eth_blockNumber,
         mungers=None,
     )
 
     @property
     def block_number(self) -> BlockNumber:
-        return self._block_number()
+        return self.get_block_number()
 
     @property
     def blockNumber(self) -> BlockNumber:
@@ -414,8 +421,14 @@ class Eth(ModuleV2, Module):
         mungers=[default_root_munger]
     )
 
+    @deprecated_for("wait_for_transaction_receipt")
     def waitForTransactionReceipt(
         self, transaction_hash: _Hash32, timeout: int = 120, poll_latency: float = 0.1
+    ) -> TxReceipt:
+        return self.wait_for_transaction_receipt(transaction_hash, timeout, poll_latency)
+
+    def wait_for_transaction_receipt(
+        self, transaction_hash: _Hash32, timeout: int = 120, poll_latency: float = 0.1
     ) -> TxReceipt:
         try:
             return wait_for_transaction_receipt(self.web3, transaction_hash, timeout, poll_latency)
@@ -427,24 +440,34 @@ class Eth(ModuleV2, Module):
                 )
             )
 
-    getTransactionReceipt: Method[Callable[[_Hash32], TxReceipt]] = Method(
+    get_transaction_receipt: Method[Callable[[_Hash32], TxReceipt]] = Method(
         RPC.eth_getTransactionReceipt,
         mungers=[default_root_munger]
     )
 
-    getTransactionCount: Method[Callable[..., Nonce]] = Method(
+    get_transaction_count: Method[Callable[..., Nonce]] = Method(
         RPC.eth_getTransactionCount,
         mungers=[block_id_munger],
     )
 
+    @deprecated_for("replace_transaction")
     def replaceTransaction(self, transaction_hash: _Hash32, new_transaction: TxParams) -> HexBytes:
+        return self.replace_transaction(transaction_hash, new_transaction)
+
+    def replace_transaction(self, transaction_hash: _Hash32, new_transaction: TxParams) -> HexBytes:
         current_transaction = get_required_transaction(self.web3, transaction_hash)
         return replace_transaction(self.web3, current_transaction, new_transaction)
 
     # todo: Update Any to stricter kwarg checking with TxParams
     # https://github.com/python/mypy/issues/4441
+    @deprecated_for("modify_transaction")
     def modifyTransaction(
         self, transaction_hash: _Hash32, **transaction_params: Any
+    ) -> HexBytes:
+        return self.modify_transaction(transaction_hash, **transaction_params)
+
+    def modify_transaction(
+        self, transaction_hash: _Hash32, **transaction_params: Any
     ) -> HexBytes:
         assert_valid_transaction_params(cast(TxParams, transaction_params))
         current_transaction = get_required_transaction(self.web3, transaction_hash)
@@ -466,12 +489,12 @@ class Eth(ModuleV2, Module):
             )
         return (transaction,)
 
-    sendTransaction: Method[Callable[[TxParams], HexBytes]] = Method(
+    send_transaction: Method[Callable[[TxParams], HexBytes]] = Method(
         RPC.eth_sendTransaction,
         mungers=[send_transaction_munger]
     )
 
-    sendRawTransaction: Method[Callable[[Union[HexStr, bytes]], HexBytes]] = Method(
+    send_raw_transaction: Method[Callable[[Union[HexStr, bytes]], HexBytes]] = Method(
         RPC.eth_sendRawTransaction,
         mungers=[default_root_munger],
     )
@@ -491,12 +514,12 @@ class Eth(ModuleV2, Module):
         mungers=[sign_munger],
     )
 
-    signTransaction: Method[Callable[[TxParams], SignedTx]] = Method(
+    sign_transaction: Method[Callable[[TxParams], SignedTx]] = Method(
         RPC.eth_signTransaction,
         mungers=[default_root_munger],
     )
 
-    signTypedData: Method[Callable[..., HexStr]] = Method(
+    sign_typed_data: Method[Callable[..., HexStr]] = Method(
         RPC.eth_signTypedData,
         mungers=[default_root_munger],
     )
@@ -536,7 +559,7 @@ class Eth(ModuleV2, Module):
 
         return params
 
-    estimateGas: Method[Callable[..., Wei]] = Method(
+    estimate_gas: Method[Callable[..., Wei]] = Method(
         RPC.eth_estimateGas,
         mungers=[estimate_gas_munger]
     )
@@ -577,32 +600,32 @@ class Eth(ModuleV2, Module):
         mungers=[filter_munger],
     )
 
-    getFilterChanges: Method[Callable[[HexStr], List[LogReceipt]]] = Method(
+    get_filter_changes: Method[Callable[[HexStr], List[LogReceipt]]] = Method(
         RPC.eth_getFilterChanges,
         mungers=[default_root_munger]
     )
 
-    getFilterLogs: Method[Callable[[HexStr], List[LogReceipt]]] = Method(
+    get_filter_logs: Method[Callable[[HexStr], List[LogReceipt]]] = Method(
         RPC.eth_getFilterLogs,
         mungers=[default_root_munger]
     )
 
-    getLogs: Method[Callable[[FilterParams], List[LogReceipt]]] = Method(
+    get_logs: Method[Callable[[FilterParams], List[LogReceipt]]] = Method(
         RPC.eth_getLogs,
         mungers=[default_root_munger]
     )
 
-    submitHashrate: Method[Callable[[int, _Hash32], bool]] = Method(
+    submit_hashrate: Method[Callable[[int, _Hash32], bool]] = Method(
         RPC.eth_submitHashrate,
         mungers=[default_root_munger],
     )
 
-    submitWork: Method[Callable[[int, _Hash32, _Hash32], bool]] = Method(
+    submit_work: Method[Callable[[int, _Hash32, _Hash32], bool]] = Method(
         RPC.eth_submitWork,
         mungers=[default_root_munger],
     )
 
-    uninstallFilter: Method[Callable[[HexStr], bool]] = Method(
+    uninstall_filter: Method[Callable[[HexStr], bool]] = Method(
         RPC.eth_uninstallFilter,
         mungers=[default_root_munger],
     )
@@ -625,25 +648,39 @@ class Eth(ModuleV2, Module):
         else:
             return ContractFactory
 
+    @deprecated_for("set_contract_factory")
     def setContractFactory(
         self, contractFactory: Type[Union[Contract, ConciseContract, ContractCaller]]
+    ) -> None:
+        return self.set_contract_factory(contractFactory)
+
+    def set_contract_factory(
+        self, contractFactory: Type[Union[Contract, ConciseContract, ContractCaller]]
     ) -> None:
         self.defaultContractFactory = contractFactory
 
     def getCompilers(self) -> NoReturn:
         raise DeprecationWarning("This method has been deprecated as of EIP 1474.")
 
-    getWork: Method[Callable[[], List[HexBytes]]] = Method(
+    get_work: Method[Callable[[], List[HexBytes]]] = Method(
         RPC.eth_getWork,
         mungers=None,
     )
 
+    @deprecated_for("generate_gas_price")
     def generateGasPrice(self, transaction_params: Optional[TxParams] = None) -> Optional[Wei]:
+        return self.generate_gas_price(transaction_params)
+
+    def generate_gas_price(self, transaction_params: Optional[TxParams] = None) -> Optional[Wei]:
         if self.gasPriceStrategy:
             return self.gasPriceStrategy(self.web3, transaction_params)
         return None
 
+    @deprecated_for("set_gas_price_strategy")
     def setGasPriceStrategy(self, gas_price_strategy: GasPriceStrategy) -> None:
+        return self.set_gas_price_strategy(gas_price_strategy)
+
+    def set_gas_price_strategy(self, gas_price_strategy: GasPriceStrategy) -> None:
         self.gasPriceStrategy = gas_price_strategy
 
     # Deprecated Methods
@@ -659,5 +696,27 @@ class Eth(ModuleV2, Module):
     getTransactionByBlock = DeprecatedMethod(get_transaction_by_block,
                                              'getTransactionByBlock',
                                              'get_transaction_by_block')
+    getTransactionCount = DeprecatedMethod(get_transaction_count,
+                                           'getTransactionCount',
+                                           'get_transaction_count')
     getUncleByBlock = DeprecatedMethod(get_uncle_by_block, 'getUncleByBlock', 'get_uncle_by_block')
     getUncleCount = DeprecatedMethod(get_uncle_count, 'getUncleCount', 'get_uncle_count')
+    sendTransaction = DeprecatedMethod(send_transaction, 'sendTransaction', 'send_transaction')
+    signTransaction = DeprecatedMethod(sign_transaction, 'signTransaction', 'sign_transaction')
+    signTypedData = DeprecatedMethod(sign_typed_data, 'signTypedData', 'sign_typed_data')
+    submitHashrate = DeprecatedMethod(submit_hashrate, 'submitHashrate', 'submit_hashrate')
+    submitWork = DeprecatedMethod(submit_work, 'submitWork', 'submit_work')
+    getLogs = DeprecatedMethod(get_logs, 'getLogs', 'get_logs')
+    estimateGas = DeprecatedMethod(estimate_gas, 'estimateGas', 'estimate_gas')
+    sendRawTransaction = DeprecatedMethod(send_raw_transaction,
+                                          'sendRawTransaction',
+                                          'send_raw_transaction')
+    getTransactionReceipt = DeprecatedMethod(get_transaction_receipt,
+                                             'getTransactionReceipt',
+                                             'get_transaction_receipt')
+    uninstallFilter = DeprecatedMethod(uninstall_filter, 'uninstallFilter', 'uninstall_filter')
+    getFilterLogs = DeprecatedMethod(get_filter_logs, 'getFilterLogs', 'get_filter_logs')
+    getFilterChanges = DeprecatedMethod(get_filter_changes,
+                                        'getFilterChanges',
+                                        'get_filter_changes')
+    getWork = DeprecatedMethod(get_work, 'getWork', 'get_work')
